@@ -264,7 +264,7 @@ class Server(object):
                 self.logger.warning('Method %s not supported', method)
                 r = self._method_not_found()
         if not isinstance(r, dict):
-            return r
+            return r or []
         if self.http_compression and \
                 len(r['response']) >= self.compression_threshold:
             encodings = [e.split(';')[0].strip() for e in
@@ -374,7 +374,10 @@ class Server(object):
         if packets is not None:
             if headers is None:
                 headers = []
-            headers += [('Content-Type', 'application/octet-stream')]
+            if b64:
+                headers += [('Content-Type', 'text/plain; charset=UTF-8')]
+            else:
+                headers += [('Content-Type', 'application/octet-stream')]
             return {'status': '200 OK',
                     'headers': headers,
                     'response': payload.Payload(packets=packets).encode(b64)}
